@@ -133,9 +133,9 @@ class DatabaseAbstractionLayer(object):
             except ImportError as _err:
                 raise Exception(import_error_to_help(_module="pyodbc", _err_obj=_err,
                                                      _pip_package="pyodbc",
-                                                     _apt_package="None",
+                                                     _apt_package=None,
                                                      _win_package=None,
-                                                     _import_comment="2014-04-16: " +
+                                                     _import_comment="(For Linux) 2014-04-16: " +
                                                                      "No apt package (python3-pyodbc)"+
                                                                      " available at this time."))
             import platform
@@ -144,9 +144,9 @@ class DatabaseAbstractionLayer(object):
 
             if self.db_type == DB_SQLSERVER:
                 if platform.system().lower() == 'linux':
-                    _connection_string = "DRIVER=FreeTDS;SERVER=" + self.db_server + ";DATABASE=" + \
-                                         self.db_databasename +";TDS VERSION=8.0;UID=" + self.db_username + ";PWD=" + \
-                                         self.db_password + ";PORT="+str(self.db_port) + ";Trusted_Connection=no"
+                    _connection_string = "DRIVER={FreeTDS};SERVER=" + self.db_server + ";DATABASE=" + \
+                                         self.db_databasename +";TDS_VERSION=8.0;UID=" + self.db_username + ";PWD=" + \
+                                         self.db_password + ";PORT="+str(self.db_port) + ";Trusted_Connection=no;"
                 elif platform.system().lower() == 'windows':
                     _connection_string = "Driver={SQL Server};Server=" + self.db_server + ";DATABASE=" + \
                                          self.db_databasename +";UID=" + self.db_username + ";PWD=" + self.db_password +\
@@ -171,6 +171,7 @@ class DatabaseAbstractionLayer(object):
                 #_connection_string = "DSN=" + self.db_server + ";UID=" + self.db_username + ";PWD=" + self.db_password
                 _connection = pyodbc.connect(_connection_string, autocommit=self.db_autocommit)
 
+
                 # DSN-less?{IBM DB2 ODBC DRIVER} ?? http://www.webmasterworld.com/forum88/4434.htm
                 _connection_string =  "Driver=" + drivername + ";Database=" + self.db_databasename +";hostname=" + \
                                       self.db_server + ";port="+str(self.db_port) + ";protocol=TCPIP; uid=" + \
@@ -187,10 +188,10 @@ class DatabaseAbstractionLayer(object):
             except ImportError as _err:
                 raise Exception(import_error_to_help(_module="cx_Oracle", _err_obj=_err,
                                                      _pip_package="cx_Oracle",
-                                                     _apt_package="None",
+                                                     _apt_package=None,
                                                      _win_package="Download and install binary .msi package from " +
                                                                   "http://cx-oracle.sourceforge.net/ and install.",
-                                                     _import_comment="2014-04-16: No python3-pyodbc available at" +
+                                                     _import_comment="(Linux) 2014-04-16: No python3-pyodbc available at" +
                                                                      " build time."))
 
             _connection_string = self.db_username + '/' +  self.db_password + '@' + self.db_server + ':' + \
