@@ -3,23 +3,23 @@ Created on Jan 12, 2014
 
 @author: Nicklas Boerjesson
 """
-from qal.dataset.flatfile import Flatfile_Dataset
-from qal.dataset.xpath import XPath_Dataset
-from qal.dataset.rdbms import RDBMS_Dataset
-from qal.dataset.spreadsheet import Spreadsheet_Dataset
+from qal.dataset.flatfile import FlatfileDataset
+from qal.dataset.xpath import XpathDataset
+from qal.dataset.rdbms import RDBMSDataset
+from qal.dataset.spreadsheet import SpreadsheetDataset
 
 
 def dataset_from_resource(_resource):
     """Create a qal dataset from a resource"""
     try:
         if _resource.type.upper() == "FLATFILE":
-            _ds =  Flatfile_Dataset(_resource = _resource)
+            _ds =  FlatfileDataset(_resource = _resource)
         elif _resource.type.upper() == "XPATH":
-            _ds =  XPath_Dataset(_resource = _resource)
+            _ds =  XpathDataset(_resource = _resource)
         elif _resource.type.upper() == "RDBMS":
-            _ds =  RDBMS_Dataset(_resource = _resource)
+            _ds =  RDBMSDataset(_resource = _resource)
         elif _resource.type.upper() == "SPREADSHEET":
-            _ds =  Spreadsheet_Dataset(_resource = _resource)
+            _ds =  SpreadsheetDataset(_resource = _resource)
         else:
             raise Exception("qal.dataset.factory.dataset_from_resource: Unsupported source resource type: " + str(_resource.type.upper()))
     except Exception as e:
